@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2023 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -18,8 +18,8 @@
 package handlers
 
 import (
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"go.mongodb.org/mongo-driver/bson"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // JumboChunksHandler
